@@ -59,6 +59,12 @@ def format_index(body: Json) -> Json:
         result["worst_indexed_level"] = body["worstIndexedLevel"]
     if "maxNumCoverCells" in body:
         result["max_num_cover_cells"] = body["maxNumCoverCells"]
+    if "storedValues" in body:
+        result["storedValues"] = body["storedValues"]
+    if "cacheEnabled" in body:
+        result["cacheEnabled"] = body["cacheEnabled"]
+    if "legacyPolygons" in body:
+        result["legacyPolygons"] = body["legacyPolygons"]
 
     return verify_format(body, result)
 
@@ -208,6 +214,20 @@ def format_collection(body: Json) -> Json:
     if "schema" in body:
         result["schema"] = body["schema"]
 
+    # New in 3.10
+    if "computedValues" in body:
+        result["computedValues"] = [
+            {
+                "name": cv["name"],
+                "expression": cv["expression"],
+                "overwrite": cv["overwrite"],
+                "computedOn": cv["computedOn"],
+                "keepNull": cv["keepNull"],
+                "failOnWarning": cv["failOnWarning"],
+            }
+            for cv in body["computedValues"]
+        ]
+
     return verify_format(body, result)
 
 
@@ -1141,3 +1161,47 @@ def format_query_cache_entry(body: Json) -> Json:
         result["data_sources"] = body["dataSources"]
 
     return verify_format(body, result)
+
+
+def format_query_rule_item(body: Json) -> Json:
+    """Format AQL query rule item.
+
+    :param body: Input body.
+    :type body: dict
+    :return: Formatted body.
+    :rtype: dict
+    """
+    result = {}
+
+    if "name" in body:
+        result["name"] = body["name"]
+    if "flags" in body:
+        result["flags"] = format_query_rule_item_flags(body["flags"])
+
+    return verify_format(body, result)
+
+
+def format_query_rule_item_flags(body: Json) -> Json:
+    """Format AQL query rule item flags.
+
+    :param body: Input body.
+    :type body: dict
+    :return: Formatted body.
+    :rtype: dict
+    """
+    result = {}
+
+    if "hidden" in body:
+        result["hidden"] = body["hidden"]
+    if "clusterOnly" in body:
+        result["clusterOnly"] = body["clusterOnly"]
+    if "canBeDisabled" in body:
+        result["canBeDisabled"] = body["canBeDisabled"]
+    if "canCreateAdditionalPlans" in body:
+        result["canCreateAdditionalPlans"] = body["canCreateAdditionalPlans"]
+    if "disabledByDefault" in body:
+        result["disabledByDefault"] = body["disabledByDefault"]
+    if "enterpriseOnly" in body:
+        result["enterpriseOnly"] = body["enterpriseOnly"]
+
+    return verify_format(body, result)
